@@ -1,5 +1,5 @@
 #!/bin/bash
-mversion=4.0
+mversion=4.1
 TTSENGINE=verbio
 
 echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
@@ -24,7 +24,7 @@ install -m $perm_dir $src/bin/verbiot2f $dst/usr/bin
 #part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
-echo $n "Enter apache web root directory[$wwwdirselect]: $c"
+echo -n "Enter apache web root directory[$wwwdirselect]: "
 read wwwdiruser
 if [ -n "$wwwdiruser" ]; then
 	wwwdirselect=$wwwdiruser
